@@ -1,2 +1,2 @@
-//pub(crate) mod csv;
+pub(crate) mod csv;
 pub(crate) mod sled;
